//PlagScan API usage example in JAVA
//REQUIRES httpcomponents-client-4.5.3 lib AND java-json lib
//Make sure to insert your credentials into client_id and client_secret  
//METHOD GET ACCESS TOKEN
package api.code.example;

import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.List;
import org.apache.http.HttpEntity;
import org.apache.http.NameValuePair;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.client.utils.URIBuilder;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.json.JSONException;
import org.json.JSONObject;

public class GetAccessToken {

    /*
    / CHANGE THE client_id AND client_secret VARIABLE WITH YOUR OWN TO GET ACCESS TO YOUR DATA
    */
    static public String client_id = "";
    static public String client_secret = "";

    static private String url = "https://api.plagscan.com/v3/token";
    
    public static String request() throws IOException{
        //Create the client to make the request
        CloseableHttpClient client = HttpClients.createDefault();
        //Create the request method with the url
        HttpPost request = new HttpPost(url);

		if((client_id.length()<=0)||(client_secret.length()<=0))
			System.err.println("Check configuration; client id and client secret need to be set up!");
			
        //Adding the parameters
        List<NameValuePair> params = new ArrayList<NameValuePair>(2);
        params.add(new BasicNameValuePair("client_id", client_id));
        params.add(new BasicNameValuePair("client_secret", client_secret));
        request.setEntity(new UrlEncodedFormEntity(params, "UTF-8"));

        //Execute the request and get response
        CloseableHttpResponse response = client.execute(request);
		if(response.getStatusLine().getStatusCode()!=200){
			System.out.println("GetAccessToken request returned: "+response.getStatusLine());
			//return null;
		}
		
		String strResponse = null;
        try{
          HttpEntity entity = response.getEntity();
          if(entity != null){
            strResponse = EntityUtils.toString(entity);
            /*
            //We can show the response string directly
            System.out.println(strResponse);
            */
          }
        }finally{
          response.close();
        }
        return strResponse;
    }
    
    /**
     * @param jsonResponse the raw JSON output returned by a get access token request
     */
	public static String extractToken(String jsonResponse) throws JSONException{
		JSONObject json = new JSONObject(jsonResponse);
		String access_token = "";
		try{
			access_token = json.getString("access_token");
		}catch(Exception e){
			System.err.println("ERROR No access token received, instead found:");
			System.err.println(jsonResponse);
			System.exit(1);
		}
		return access_token;
	}
    
    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) throws IOException, URISyntaxException, JSONException {
		
		if((args.length<2)&&(client_id.length()<=0)&&(client_secret.length()<=0)){
			System.out.println("GetAccessToken CLIENT_ID CLIENT_SECRET");
			System.out.println("Paramter CLIENT_ID: Your PlagScan Client ID (optional, can also be inline - static private String client_id)");
			System.out.println("Paramter CLIENT_SECRET: Your PlagScan API Key (optional, can also be inline - static private String client_secret)");
		}else{
			client_id=args[0];
			if(args.length==2)
				client_secret=args[1];
			System.out.println("Using Client ID "+client_id+" :");
		}
		
		String json=request();
		System.out.println(json);
		String token=extractToken(json);
		System.out.println("PlagScan Token : "+token);
    }
}
