//PlagScan API usage example in JAVA
// REQUIRES httpcomponents-client-4.5.3 lib AND java-json lib
//Make sure to change access_token variable
//METHOD RETRIEVE
package api.code.example;

import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import org.apache.http.HttpEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.client.utils.URIBuilder;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import org.json.JSONException;
import org.json.JSONObject;


public class ListDocuments {
    static private String repo_url = "https://api.plagscan.com/v3/repositories/documents";
    static private String user_url = "https://api.plagscan.com/v3/users/";
        
    /**
     * @param access_token
     */    
    public static String listOrgaRepository(String access_token) throws IOException, URISyntaxException, JSONException{

		String strResponse="ERROR";
		
        //Create the client to make the request
        CloseableHttpClient client = HttpClients.createDefault();
        //Create the request method with the url
        /*
        ****** MUST ADD THE ID OF THE DOCUMENT TO THE URL ******
        */
        HttpGet request = new HttpGet(repo_url);

        //Adding to the URL the parameters (because it is a GET request)
        URI uri = new URIBuilder(request.getURI())
                .addParameter("access_token", access_token)
                .build();
        ((HttpRequestBase ) request).setURI(uri);

        //Execute the request and get response
        CloseableHttpResponse response = client.execute(request);

        try{
          HttpEntity entity = response.getEntity();
          if(entity != null){
            strResponse = EntityUtils.toString(entity);
            //We can show the response string directly
            //System.out.println(strResponse);

            //Also we can get the JSON object and for example show the PlagLevel
            //JSONObject json = new JSONObject(strResponse);
          }
        }finally{
          response.close();
        }
        return strResponse;    
    }
    
    /**
     * @param int userID - the PlagScan ID of the user whose documents are requested
     */    
    public static String listUserDocsInRepository(int userID, String access_token) throws IOException, URISyntaxException, JSONException{

		String strResponse = "ERROR";
		
        //Create the client to make the request
        CloseableHttpClient client = HttpClients.createDefault();
        //Create the request method with the url
        /*
        ****** MUST ADD THE ID OF THE DOCUMENT TO THE URL ******
        */
        HttpGet request = new HttpGet(user_url+userID+"/repository/documents");

        //Adding to the URL the parameters (because it is a GET request)
        URI uri = new URIBuilder(request.getURI())
                .addParameter("access_token", access_token)
                .build();
        ((HttpRequestBase ) request).setURI(uri);

        //Execute the request and get response
        CloseableHttpResponse response = client.execute(request);

        try{
          HttpEntity entity = response.getEntity();
          if(entity != null){
            strResponse = EntityUtils.toString(entity);
            //We can show the response string directly
            //System.out.println(strResponse);

            //Also we can get the JSON object and for example show the PlagLevel
            //JSONObject json = new JSONObject(strResponse);
          }
        }finally{
          response.close();
        }
        return strResponse;    
    }
 
    /**
     * @param int userID - the PlagScan ID of the user whose documents are requested
     * @param String shared - can be null to list all, "withMe" returns the documents shared with the user, and "byMe" returns the documents shared by the user.
     */    
    public static String listUserDocs(int userID, String shared, String access_token) throws IOException, URISyntaxException, JSONException{

		String strResponse = "ERROR";
		
        //Create the client to make the request
        CloseableHttpClient client = HttpClients.createDefault();
        //Create the request method with the url
        /*
        ****** MUST ADD THE ID OF THE DOCUMENT TO THE URL ******
        */
        HttpGet request = new HttpGet(user_url+userID+"/documents");

        //Adding to the URL the parameters (because it is a GET request)
        URIBuilder ub = new URIBuilder(request.getURI())
                .addParameter("access_token", access_token);
                //ub.addParameter("mode", "1");
                if(shared!=null)
                	ub.addParameter("shared", shared); //withMe, byMe - With "withMe" value return the documents shared with the user, and "byMe" return the documents shared by the user. If it is not set by default return all the documents of the user
		URI uri = ub.build();
        ((HttpRequestBase ) request).setURI(uri);

        //Execute the request and get response
        CloseableHttpResponse response = client.execute(request);

        try{
          HttpEntity entity = response.getEntity();
          if(entity != null){
            strResponse = EntityUtils.toString(entity);
            //We can show the response string directly
            //System.out.println(strResponse);

            //Also we can get the JSON object and for example show the PlagLevel
            //JSONObject json = new JSONObject(strResponse);
          }
        }finally{
          response.close();
        }
        return strResponse;    
    }    
}
