//PlagScan API usage example in JAVA
// REQUIRES httpcomponents-client-4.5.3 lib AND java-json lib
//Make sure to change access_token variable
//METHOD SOURCE
package api.code.example;

import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import org.apache.http.HttpEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.client.utils.URIBuilder;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import org.json.JSONException;
import org.json.JSONObject;


public class Source {
    static private String url = "https://api.plagscan.com/v3/documents/";
        
    /**
     * @param int docID - the PlagScan ID of the document to be queried
     * @returns List of sources ordered by number of matches in json format
     */    
    public static String[] getList(int docID, String access_token) throws IOException, URISyntaxException, JSONException{

        //Create the client to make the request
        CloseableHttpClient client = HttpClients.createDefault();
        //Create the request method with the url
        /*
        ****** MUST ADD THE ID OF THE DOCUMENT TO THE URL ******
        */
        HttpGet request = new HttpGet(url+docID+"/sources");

        //Adding to the URL the parameters (because it is a GET request)
        URI uri = new URIBuilder(request.getURI())
                .addParameter("access_token", access_token)
                .addParameter("format", "json")
                .build();
        ((HttpRequestBase ) request).setURI(uri);

        //Execute the request and get response
        CloseableHttpResponse response = client.execute(request);

        try{
          HttpEntity entity = response.getEntity();
          if(entity != null){
            String strResponse = EntityUtils.toString(entity);
            //We can show the response string directly
            System.out.println(strResponse);
            String[] ret = new String[] {strResponse};
            return ret;

            //Also we can get the JSON object and for example show the PlagLevel
            //JSONObject json = new JSONObject(strResponse);
          }
        }finally{
          response.close();
        }
        return null;    
    }

    /**
     * @param int docID - the PlagScan ID of the document to be queried
     * @param int source - the source number within the report of docID
     * @returns Plaintext content of the source
     */    
    public static String getSource(int docID, int source, String access_token) throws IOException, URISyntaxException, JSONException{

        //Create the client to make the request
        CloseableHttpClient client = HttpClients.createDefault();
        //Create the request method with the url
        /*
        ****** MUST ADD THE ID OF THE DOCUMENT TO THE URL ******
        */
        HttpGet request = new HttpGet(url+docID+"/highlight");

        //Adding to the URL the parameters (because it is a GET request)
        URI uri = new URIBuilder(request.getURI())
                .addParameter("access_token", access_token)
                .addParameter("source", ""+source)
                .addParameter("format", "raw")
                .build();
        ((HttpRequestBase ) request).setURI(uri);

        //Execute the request and get response
        CloseableHttpResponse response = client.execute(request);

        try{
          HttpEntity entity = response.getEntity();
          if(entity != null){
            String strResponse = EntityUtils.toString(entity);
            //We can show the response string directly
            System.out.println(strResponse);
            return strResponse;

            //Also we can get the JSON object and for example show the PlagLevel
            //JSONObject json = new JSONObject(strResponse);
          }
        }finally{
          response.close();
        }
        return null;    
    }
    
    /**
     * @param int docID - the PlagScan ID of the document to be queried
     * @param int source - the source number within the report of docID
     * @returns Plaintext content of the source with minimal markup
     */    
    public static String getSourceMinimal(int docID, int source, String access_token) throws IOException, URISyntaxException, JSONException{

        //Create the client to make the request
        CloseableHttpClient client = HttpClients.createDefault();
        //Create the request method with the url
        /*
        ****** MUST ADD THE ID OF THE DOCUMENT TO THE URL ******
        */
        HttpGet request = new HttpGet(url+docID+"/highlight");

        //Adding to the URL the parameters (because it is a GET request)
        URI uri = new URIBuilder(request.getURI())
                .addParameter("access_token", access_token)
                .addParameter("source", ""+source)
                .addParameter("format", "minimal")
                .build();
        ((HttpRequestBase ) request).setURI(uri);

        //Execute the request and get response
        CloseableHttpResponse response = client.execute(request);

        try{
          HttpEntity entity = response.getEntity();
          if(entity != null){
            String strResponse = EntityUtils.toString(entity);
            //We can show the response string directly
            System.out.println(strResponse);
            return strResponse;

            //Also we can get the JSON object and for example show the PlagLevel
            //JSONObject json = new JSONObject(strResponse);
          }
        }finally{
          response.close();
        }
        return null;    
    }
}
