//PlagScan API usage example in JAVA
// REQUIRES httpcomponents-client-4.5.3 lib AND java-json lib
//Make sure to change access_token variable
//METHOD SUBMIT DOCUMENT
package api.code.example;

import java.io.File;
import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.List;
import org.apache.http.HttpEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.client.utils.URIBuilder;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.mime.MultipartEntityBuilder;
import org.apache.http.entity.mime.content.FileBody;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import org.json.JSONException;
import org.json.JSONObject;


public class Submit {
    static private String url = "https://api.plagscan.com/v3/documents";

	public static String sendFile(String filename, String token) throws IOException, URISyntaxException, JSONException{
		return Submit.sendFile(filename, token, null, null);
	}

    /**
     * @param filename
     * @param token
     * @param toRepo - can be null for ignore, "1" for true or "0" for false
     * @param userID - can be null for ignore, or ID of the receiving user account
     */    
    public static String sendFile(String filename, String token, String toRepo, String userID) throws IOException, URISyntaxException, JSONException{
    	
        //Create the client to make the request
        CloseableHttpClient client = HttpClients.createDefault();
        //Create the request method with the url
        HttpPost request = new HttpPost(url);

		File file = new File(filename);
		if(!file.exists() || file.isDirectory()){
			System.out.println("Submit cannot find file '"+filename+"'");
			return null;
		}

        //Adding the parameters
        HttpEntity reqEntity = MultipartEntityBuilder.create()
                .addBinaryBody("fileUpload", file)
                .build();

        request.setEntity(reqEntity);

        //Adding to the URL the parameters (because it is a GET request)
        URIBuilder ub = new URIBuilder(request.getURI())
                .addParameter("access_token", token);
                if(toRepo!=null)
                	ub.addParameter("toRepository", toRepo); //"1" for true or "0" for false
                if(userID!=null)
                	ub.addParameter("userID", userID); //ID of the receiving user account
		URI uri = ub.build();
        ((HttpRequestBase ) request).setURI(uri);

        //Execute the request and get response
        CloseableHttpResponse response = client.execute(request);
		if((response.getStatusLine().getStatusCode()<200)||(response.getStatusLine().getStatusCode()>210)){
			System.out.println("GetAccessToken request returned: "+response.getStatusLine());
			//return null;
		}
		String strResponse=null;
        try{
          HttpEntity entity = response.getEntity();
          if(entity != null){
          
            strResponse = EntityUtils.toString(entity);
            //We can show the response string directly
           	//System.out.println(strResponse);
            
          }
        }finally{
          response.close();
        }
    	
    	return strResponse;
    }
    
    /**
     * @param jsonResponse the raw JSON output returned by a get access token request
     */	
	public static int extractDocId(String jsonResponse) throws JSONException{
		JSONObject json = new JSONObject(jsonResponse);
		int documentPlagScanID = json.getJSONObject("data").getInt("docID");
		return documentPlagScanID;
	}
        	
    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) throws IOException, URISyntaxException, JSONException {
        /*
        / CHANGE THE access_token VARIABLE WITH YOUR OWN TO GET ACCESS TO YOUR DATA
        */
        String access_token = "";

		String filename;
		if(args.length<=0){
			System.out.println("Submit FILE TOKEN");
			System.out.println("Paramter FILE: The document file to upload (optional, if not provided system will look for testfile.txt)");
			System.out.println("Paramter TOKEN: The access token (optional, if not provided system will try to call GetAccessToken)");
			filename="./testfile.txt";
		}else{
			filename=args[0];
		}
		if(args.length==2){
			//System.out.println("Using command line parameter token");
			access_token = args[1];
		}else{
			//System.out.println("Trying to request token via GetAccessToken");
			access_token = GetAccessToken.extractToken(GetAccessToken.request());
		}

		String json = sendFile(filename,access_token);
		System.out.println("Uploaded file "+filename+" : "+json);
		int documentPlagScanID = extractDocId(json);
		System.out.println("PlagScan document ID : "+documentPlagScanID);
    }
}
